from experiment.luna.pipeline.dependency_provider import get_record_provider, GOLD_TRANSCRIPT, \
    get_multiple_files_repository, GOLD_TRANSCRIPT_SPACY
from experiment.luna.pipeline.task.luna_gold_transcript_processor import LunaGoldTranscriptProcessor
from experiment.pos_processing.gold_transcript_spacy_token_pos_processing_task import \
    GoldTranscriptSpacyTokenPosProcessingTask
from sziszapangma.integration.experiment_manager import ExperimentManager
from sziszapangma.integration.task.gold_transcript_task import GoldTranscriptTask


def run_luna_experiment():
    record_provider = get_record_provider()
    ExperimentManager(
        record_id_iterator=record_provider,
        processing_tasks=[
            GoldTranscriptTask(
                task_name='gold_transcript_task',
                gold_transcript_processor=LunaGoldTranscriptProcessor(record_provider),
                gold_transcript_property_name=GOLD_TRANSCRIPT,
                require_update=False
            ),
            GoldTranscriptSpacyTokenPosProcessingTask(
                task_name='gold_transcript_spacy_task',
                input_property_name=GOLD_TRANSCRIPT,
                spacy_property_name=GOLD_TRANSCRIPT_SPACY,
                require_update=True
            ),
        ],
        experiment_repository=get_multiple_files_repository(),
        relation_manager_provider=record_provider
    ).process()


if __name__ == '__main__':
    run_luna_experiment()
